@@ -36,6 +36,7 @@ import json
 import re
 import traceback
 import uuid
+import weakref
 from http.server import BaseHTTPRequestHandler
 
 import tornado
@@ -110,7 +111,8 @@ class Resource(RequestHandler):
 
     def get_current_user(self):
         session = Session.get_or_create(self.get_session_id())  # FIXME: this creates a Session instance even if the session does not exists
-        session._ = lambda *args: self._(*args)  # hack to prevent circular use, when "_" is not yet set but only in prepare()  # noqa: PLW0108
+        weakself = weakref.ref(self)
+        session._ = lambda *args: weakself()._(*args)  # hack to prevent circular use, when "_" is not yet set but only in prepare()  # noqa: PLW0108
         if not session.user.ip:
             session.user.ip = self.get_ip_address()
         return session
