@@ -44,6 +44,7 @@ define([
 	"dojo/Evented",
 	"dojo/Deferred",
 	"dojo/promise/all",
+	"dojo/query",
 	"dojo/cookie",
 	"dojo/topic",
 	"dojo/io-query",
@@ -81,7 +82,7 @@ define([
 	"umc/i18n/tools",
 	"umc/i18n!management",
 	"dojo/sniff" // has("ie"), has("ff")
-], function(declare, lang, kernel, array, baseWin, onDebounce, on, aspect, has, Evented, Deferred, all, cookie, topic,
+], function(declare, lang, kernel, array, baseWin, onDebounce, on, aspect, has, Evented, Deferred, all, query, cookie, topic,
 		ioQuery, Memory, Observable, dom, domClass, domConstruct, put, dojoHash, styles, entities, gfx, tools, login,
 		dialog, NotificationSnackbar, store, Tooltip, StackContainer, menu, MenuButton,	TabController, LiveSearch,
 		GalleryPane, ContainerWidget, Page, Form, Button, ToggleButton, Text, ConfirmDialog, NotificationsButton,
@@ -591,8 +592,39 @@ define([
 			});
 		};
 
+		// Summit
+		// This is double (showSummit2021Dialog()) but instead of adjusting the existing one, lets keep code between 5.0 and 5.2 equal.
+		var showSummitNotification = function() {
+				var endOfSummit = new Date(2026, 0, 27, 0, 0, 0);
+				var summitNotificationCookieName = `hideSummit${endOfSummit.getFullYear()}Notification`;
+				var summitHasPassed = endOfSummit < new Date();
+				var isUserAdmin = app.getModule('updater') || app.getModule('schoolrooms');
+				var dontShowNotification = !tools.status('has_free_license') || summitHasPassed || !isUserAdmin;
+				if (dontShowNotification) {
+						return;
+				}
+
+				var isDE = (kernel.locale.toLowerCase().indexOf('de') === 0);
+				var message_de = 'Univention Summit 2026 – 28. & 29. Januar in Bremen.<br />Infos & Tickets: <a href="https://www.univention-summit.de/?mtm_campaign=UCS%20User%20Benachrichtigung%20Summit%202026" target="_blank">univention-summit.de</a>';
+				var message_en = 'Univention Summit 2026 – 28th & 29th of January in Bremen.<br />Info & Tickets: <a href="https://www.univention-summit.com/?mtm_campaign=UCS%20User%20Benachrichtigung%20Summit%202026" target="_blank">univention-summit.com</a>';
+				var message = isDE ? message_de : message_en;
+				var title = "Let's connect!";
+				if (cookie(summitNotificationCookieName)) {
+						// has already been shown once, only "passive bell item"
+						// hack it in there, I dont want to make this a public API
+						NotificationsButton._addPassiveNotification({title: title, content: message});
+				} else {
+						// full notification with "active bubble"
+						var notification = dialog.notify(message, title);
+						var nowInTwoWeeks = new Date(Date.now() + (1000 * 60 * 60 * 24 * 14));
+						var expires = nowInTwoWeeks < endOfSummit ? nowInTwoWeeks : endOfSummit;
+						cookie(summitNotificationCookieName, 'true', {expires: expires.toUTCString()});
+				}
+		};
+
 		// run several checks
 		checkCertificateValidity();
+		showSummitNotification();
 		showSummit2021Dialog();
 		showSummit2021Notification();
 		showAmbassadorNotification();
@@ -1303,7 +1335,10 @@ define([
 			}
 
 			// set window title
-			window.document.title = lang.replace('{0} - {1}', [tools.status('fqdn'), window.document.title]);
+			window.document.title = tools.status('title') || lang.replace('{0} - {1}', [tools.status('fqdn'), window.document.title]);
+			if (tools.status('favicon')) {
+			    (query('link[rel="shortcut icon"]')[0] || query('link[rel="icon"]')[0] || {}).href = tools.status('favicon');
+			}
 
 			// setup menus
 			this._header.setupGui();
